comment = {
    'table-education': {
        'is_trade': "是否是技工类别？比如水电工"
    },
    'info-joboffer': {
        "ot_after_hours_unit": "加班工资开始计算的单位，比如，每天超过8小时，那么该单位就是day；如果每周超过40小时，那么单位就是week"
    },
    'table-family': {
        "relationship": "请填写你的： 配偶，子女，母亲，父亲，兄弟姐妹，包括同母异父/同母异父的兄弟姐妹，"
    }

}
